==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPageEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDetailDescription } from "./WebPageEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPageEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPageEventArgsDetailDescriptionMetadata, _super);
    function WebPageEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPageEventArgsDetailDescriptionMetadata.a == null) {
            WebPageEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageEventArgsDetailDescriptionMetadata.c(WebPageEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebPageEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPageEventArgsDetailDescriptionMetadata.a);
    };
    WebPageEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PageEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Previous", "Number:double");
        a.item("Current", "Number:double");
    };
    WebPageEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPageEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebPageEventArgsDetail", function () { return new WebPageEventArgsDetailDescription(); });
        a.z("WebPageEventArgsDetail", WebPageEventArgsDetailDescriptionMetadata.a);
    };
    WebPageEventArgsDetailDescriptionMetadata.$t = markType(WebPageEventArgsDetailDescriptionMetadata, 'WebPageEventArgsDetailDescriptionMetadata');
    WebPageEventArgsDetailDescriptionMetadata.a = null;
    return WebPageEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPageEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPageEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDetailDescription } from "./WebPageEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPageEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPageEventArgsDetailDescriptionMetadata, _super);
    function WebPageEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPageEventArgsDetailDescriptionMetadata.a == null) {
            WebPageEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageEventArgsDetailDescriptionMetadata.c(WebPageEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPageEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPageEventArgsDetailDescriptionMetadata.a);
    };
    WebPageEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PageEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Previous", "Number:double");
        a.item("Current", "Number:double");
    };
    WebPageEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPageEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebPageEventArgsDetail", function () { return new WebPageEventArgsDetailDescription(); });
        a.ab("WebPageEventArgsDetail", WebPageEventArgsDetailDescriptionMetadata.a);
    };
    WebPageEventArgsDetailDescriptionMetadata.$t = markType(WebPageEventArgsDetailDescriptionMetadata, 'WebPageEventArgsDetailDescriptionMetadata');
    WebPageEventArgsDetailDescriptionMetadata.a = null;
    return WebPageEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPageEventArgsDetailDescriptionMetadata };
